@@ -4,8 +4,6 @@
 
 import {Class, TypedArray, ObservableLike, Primitive} from './types';
 
-export {Class, TypedArray, ObservableLike, Primitive};
-
 const typedArrayTypeNames = [
 	'Int8Array',
 	'Uint8Array',
@@ -49,6 +47,8 @@ const objectTypeNames = [
 	'DataView',
 	'Promise',
 	'URL',
+	'FormData',
+	'URLSearchParams',
 	'HTMLElement',
 	...typedArrayTypeNames
 ] as const;
@@ -260,9 +260,8 @@ is.primitive = (value: unknown): value is Primitive => is.null_(value) || isPrim
 is.integer = (value: unknown): value is number => Number.isInteger(value as number);
 is.safeInteger = (value: unknown): value is number => Number.isSafeInteger(value as number);
 
-type ObjectKey = string | number | symbol;
-is.plainObject = <Value = unknown>(value: unknown): value is Record<ObjectKey, Value> => {
-	// From: https://github.com/sindresorhus/is-plain-obj/blob/master/index.js
+is.plainObject = <Value = unknown>(value: unknown): value is Record<PropertyKey, Value> => {
+	// From: https://github.com/sindresorhus/is-plain-obj/blob/main/index.js
 	if (toString.call(value) !== '[object Object]') {
 		return false;
 	}
@@ -363,6 +362,12 @@ is.nonEmptySet = <T = unknown>(value: unknown): value is Set<T> => is.set(value)
 is.emptyMap = (value: unknown): value is Map<never, never> => is.map(value) && value.size === 0;
 is.nonEmptyMap = <Key = unknown, Value = unknown>(value: unknown): value is Map<Key, Value> => is.map(value) && value.size > 0;
 
+// `PropertyKey` is any value that can be used as an object key (string, number, or symbol)
+is.propertyKey = (value: unknown): value is PropertyKey => is.any([is.string, is.number, is.symbol], value);
+is.formData = (value: unknown): value is FormData => isObjectOfType<FormData>('FormData')(value);
+
+is.urlSearchParams = (value: unknown): value is URLSearchParams => isObjectOfType<URLSearchParams>('URLSearchParams')(value);
+
 export type Predicate = (value: unknown) => boolean;
 
 type ArrayMethod = (fn: (value: unknown, index: number, array: unknown[]) => boolean, thisArg?: unknown) => boolean;
@@ -388,9 +393,18 @@ is.any = (predicate: Predicate | Predicate[], ...values: unknown[]): boolean =>
 
 is.all = (predicate: Predicate, ...values: unknown[]): boolean => predicateOnArray(Array.prototype.every, predicate, values);
 
-const assertType = (condition: boolean, description: string, value: unknown): asserts condition => {
+const assertType = (condition: boolean, description: string, value: unknown, options: {multipleValues?: boolean} = {}): asserts condition => {
 	if (!condition) {
-		throw new TypeError(`Expected value which is \`${description}\`, received value of type \`${is(value)}\`.`);
+		const {multipleValues} = options;
+		const valuesMessage = multipleValues ?
+			`received values of types ${[
+				...new Set(
+					(value as any[]).map(singleValue => `\`${is(singleValue)}\``)
+				)
+			].join(', ')}` :
+			`received value of type \`${is(value)}\``;
+
+		throw new TypeError(`Expected value which is \`${description}\`, ${valuesMessage}.`);
 	}
 };
 
@@ -495,7 +509,7 @@ interface Assert {
 	primitive: (value: unknown) => asserts value is Primitive;
 	integer: (value: unknown) => asserts value is number;
 	safeInteger: (value: unknown) => asserts value is number;
-	plainObject: <Value = unknown>(value: unknown) => asserts value is Record<ObjectKey, Value>;
+	plainObject: <Value = unknown>(value: unknown) => asserts value is Record<PropertyKey, Value>;
 	typedArray: (value: unknown) => asserts value is TypedArray;
 	arrayLike: <T = unknown>(value: unknown) => asserts value is ArrayLike<T>;
 	domElement: (value: unknown) => asserts value is HTMLElement;
@@ -513,6 +527,9 @@ interface Assert {
 	nonEmptySet: <T = unknown>(value: unknown) => asserts value is Set<T>;
 	emptyMap: (value: unknown) => asserts value is Map<never, never>;
 	nonEmptyMap: <Key = unknown, Value = unknown>(value: unknown) => asserts value is Map<Key, Value>;
+	propertyKey: (value: unknown) => asserts value is PropertyKey;
+	formData: (value: unknown) => asserts value is FormData;
+	urlSearchParams: (value: unknown) => asserts value is URLSearchParams;
 
 	// Numbers.
 	evenInteger: (value: number) => asserts value is number;
@@ -592,7 +609,7 @@ export const assert: Assert = {
 	primitive: (value: unknown): asserts value is Primitive => assertType(is.primitive(value), AssertionTypeDescription.primitive, value),
 	integer: (value: unknown): asserts value is number => assertType(is.integer(value), AssertionTypeDescription.integer, value),
 	safeInteger: (value: unknown): asserts value is number => assertType(is.safeInteger(value), AssertionTypeDescription.safeInteger, value),
-	plainObject: <Value = unknown>(value: unknown): asserts value is Record<ObjectKey, Value> => assertType(is.plainObject(value), AssertionTypeDescription.plainObject, value),
+	plainObject: <Value = unknown>(value: unknown): asserts value is Record<PropertyKey, Value> => assertType(is.plainObject(value), AssertionTypeDescription.plainObject, value),
 	typedArray: (value: unknown): asserts value is TypedArray => assertType(is.typedArray(value), AssertionTypeDescription.typedArray, value),
 	arrayLike: <T = unknown>(value: unknown): asserts value is ArrayLike<T> => assertType(is.arrayLike(value), AssertionTypeDescription.arrayLike, value),
 	domElement: (value: unknown): asserts value is HTMLElement => assertType(is.domElement(value), AssertionTypeDescription.domElement, value),
@@ -610,6 +627,9 @@ export const assert: Assert = {
 	nonEmptySet: <T = unknown>(value: unknown): asserts value is Set<T> => assertType(is.nonEmptySet(value), AssertionTypeDescription.nonEmptySet, value),
 	emptyMap: (value: unknown): asserts value is Map<never, never> => assertType(is.emptyMap(value), AssertionTypeDescription.emptyMap, value),
 	nonEmptyMap: <Key = unknown, Value = unknown>(value: unknown): asserts value is Map<Key, Value> => assertType(is.nonEmptyMap(value), AssertionTypeDescription.nonEmptyMap, value),
+	propertyKey: (value: unknown): asserts value is number => assertType(is.propertyKey(value), 'PropertyKey', value),
+	formData: (value: unknown): asserts value is FormData => assertType(is.formData(value), 'FormData', value),
+	urlSearchParams: (value: unknown): asserts value is URLSearchParams => assertType(is.urlSearchParams(value), 'URLSearchParams', value),
 
 	// Numbers.
 	evenInteger: (value: number): asserts value is number => assertType(is.evenInteger(value), AssertionTypeDescription.evenInteger, value),
@@ -620,8 +640,10 @@ export const assert: Assert = {
 	inRange: (value: number, range: number | number[]): asserts value is number => assertType(is.inRange(value, range), AssertionTypeDescription.inRange, value),
 
 	// Variadic functions.
-	any: (predicate: Predicate | Predicate[], ...values: unknown[]): void | never => assertType(is.any(predicate, ...values), AssertionTypeDescription.any, values),
-	all: (predicate: Predicate, ...values: unknown[]): void | never => assertType(is.all(predicate, ...values), AssertionTypeDescription.all, values)
+	any: (predicate: Predicate | Predicate[], ...values: unknown[]): void | never => {
+		return assertType(is.any(predicate, ...values), AssertionTypeDescription.any, values, {multipleValues: true});
+	},
+	all: (predicate: Predicate, ...values: unknown[]): void | never => assertType(is.all(predicate, ...values), AssertionTypeDescription.all, values, {multipleValues: true})
 };
 
 // Some few keywords are reserved, but we'll populate them for Node.js users
@@ -651,6 +673,8 @@ Object.defineProperties(assert, {
 
 export default is;
 
+export {Class, TypedArray, ObservableLike, Primitive} from './types';
+
 // For CommonJS default export support
 module.exports = is;
 module.exports.default = is;
