@@ -1490,6 +1490,20 @@ test('is.nonEmptyMap', t => {
 	});
 });
 
+test('is.propertyKey', t => {
+	t.true(is.propertyKey('key'));
+	t.true(is.propertyKey(42));
+	t.true(is.propertyKey(Symbol('')));
+
+	t.false(is.propertyKey(null));
+	t.false(is.propertyKey(undefined));
+	t.false(is.propertyKey(true));
+	t.false(is.propertyKey({}));
+	t.false(is.propertyKey([]));
+	t.false(is.propertyKey(new Map()));
+	t.false(is.propertyKey(new Set()));
+});
+
 test('is.any', t => {
 	t.true(is.any(is.string, {}, true, '🦄'));
 	t.true(is.any(is.object, false, {}, 'unicorns'));
@@ -1529,6 +1543,27 @@ test('is.any', t => {
 	t.throws(() => {
 		assert.any(is.string);
 	});
+
+	t.throws(() => {
+		assert.any(is.string, 1, 2, 3);
+	}, {
+		// Removes duplicates:
+		message: /received values of types `number`./
+	});
+
+	t.throws(() => {
+		assert.any(is.string, 1, [4]);
+	}, {
+		// Lists all types:
+		message: /received values of types `number`, `Array`./
+	});
+
+	t.throws(() => {
+		assert.any([is.string, is.nullOrUndefined], 1);
+	}, {
+		// Handles array as first argument:
+		message: /received values of types `number`./
+	});
 });
 
 test('is.all', t => {
@@ -1570,6 +1605,62 @@ test('is.all', t => {
 	t.throws(() => {
 		assert.all(is.string);
 	});
+
+	t.throws(() => {
+		assert.all(is.string, 1, 2, 3);
+	}, {
+		// Removes duplicates:
+		message: /received values of types `number`./
+	});
+
+	t.throws(() => {
+		assert.all(is.string, 1, [4]);
+	}, {
+		// Lists all types:
+		message: /received values of types `number`, `Array`./
+	});
+});
+
+test('is.formData', t => {
+	const data = new window.FormData();
+	t.true(is.formData(data));
+	t.false(is.formData({}));
+	t.false(is.formData(undefined));
+	t.false(is.formData(null));
+
+	t.notThrows(() => {
+		assert.formData(data);
+	});
+	t.throws(() => {
+		assert.formData({});
+	});
+	t.throws(() => {
+		assert.formData(undefined);
+	});
+	t.throws(() => {
+		assert.formData(null);
+	});
+});
+
+test('is.urlSearchParams', t => {
+	const searchParams = new URLSearchParams();
+	t.true(is.urlSearchParams(searchParams));
+	t.false(is.urlSearchParams({}));
+	t.false(is.urlSearchParams(undefined));
+	t.false(is.urlSearchParams(null));
+
+	t.notThrows(() => {
+		assert.urlSearchParams(searchParams);
+	});
+	t.throws(() => {
+		assert.urlSearchParams({});
+	});
+	t.throws(() => {
+		assert.urlSearchParams(undefined);
+	});
+	t.throws(() => {
+		assert.urlSearchParams(null);
+	});
 });
 
 test('assert', t => {
